# Connectors
A simple, lightweight set of connectors and functions to various APIs, controlled by a central broker.

## How to install
1. You must have Poetry installed. You can find instructions to do that [here](https://python-poetry.org/docs/#installation)
2. Clone this repo and `cd` into it
3. Run `poetry shell`. This will create a separate Python environment, and activate a shell inside it.
4. Run `poetry install`